@@ -16,16 +16,28 @@
 import sys
 import os
 
+# If ../muranoconductor/__init__.py exists, add ../ to Python search path, so
+# it will override what happens to be installed in /usr/(local/)lib/python...
+possible_topdir = os.path.normpath(os.path.join(os.path.abspath(__file__),
+                                                os.pardir,
+                                                os.pardir,
+                                                os.pardir))
+if os.path.exists(os.path.join(possible_topdir,
+                               'muranoconductor',
+                               '__init__.py')):
+    sys.path.insert(0, possible_topdir)
+
 from muranoconductor import config
 from muranoconductor.openstack.common import log
 from muranoconductor.openstack.common import service
 from muranoconductor.app import ConductorWorkflowService
+from muranoconductor import metadata
 
 
 def main():
     try:
         config.parse_args()
-        os.chdir(config.CONF.data_dir)
+        metadata.prepare(config.CONF.data_dir)
         log.setup('conductor')
         launcher = service.ServiceLauncher()
         launcher.launch_service(ConductorWorkflowService())
